@@ -53,7 +53,7 @@ importsDoneTimestamp = time.time()
 
 def createFolderPath(newPath):
   """
-  Create a path for a directory and all needed parent forlders
+  Create a path for a directory and all needed parent folders
   -> parent directories will be created
   -> if directory already exists, then do nothing
   -> if there is another filesystem object (like a file) with the same name, raise an exception
@@ -87,12 +87,20 @@ class ModRana:
     # constants & variable initialization
     self.dmod = None # device specific module
     self.gui = None
+    self.GUIString = ""
+    self.optLoadingOK = None
 
     self.d = {} # persistent dictionary of data
     self.m = {} # dictionary of loaded modules
     self.watches = {} # List of data change watches
     self.maxWatchId = 0
 
+    self.initInfo={
+      'modrana': self,
+      'device': None, # TODO: do this directly
+      'name': ""
+    }
+
     self.mapRotationAngle = 0 # in radians
     self.notMovingSpeed = 1 # in m/s
 
@@ -108,8 +116,15 @@ class ModRana:
     self.addTime("GUI creation")
 
     # add the startup handling core module
-    start = startup.Startup(self)
-    self.args = start.getArgs()
+    self.startup = startup.Startup(self)
+    self.args = self.startup.getArgs()
+
+    # handle any early tasks specified from CLI
+    self.startup.handleEarlyTasks()
+
+    # early CLI tasks might need a "silent" modRana
+    # so the startup announcement is here
+    print(" == modRana Starting == ")
 
     # add the paths handling core module
     self.paths = paths.Paths(self)
@@ -135,7 +150,16 @@ class ModRana:
     self.configs.loadAll()
 
     # start loading modules
-    self.loadModules()
+
+    # device module first
+    self._loadDeviceModule()
+
+    # then the GUI module
+    self._loadGUIModule()
+
+    # and all other modules
+    self._loadModules()
+
     # startup done, print some statistics
     self._startupDone()
 
@@ -147,37 +171,31 @@ class ModRana:
 
   ##  MODULE HANDLING ##
 
-  def loadModules(self):
-    """Load all modules from the specified directory"""
+  def _loadDeviceModule(self):
+    """Load the device module"""
 
     # get the device module string
     # (a unique device module string identificator)
-    # make sure there is some argument provided
-    if self.args:
-      device = self.args.d[0]
-    else:
-      # use the Neo device module as fallback
-      device = "neo"
+    if self.args.d:
+      device = self.args.d
+    else: # no device specified from CLI
+      # try to auto-detect the current device
+      from core import platform_detection
+      device = platform_detection.getBestDeviceModuleId()
 
     device = device.lower() # convert to lowercase
-    print "importing modules:"
-    start = time.clock()
-    self.initInfo={
-              'modrana': self,
-              'device': device, # TODO: do this directly
-              'name': ""
-             }
 
-    # make shortcut for the loadModule function
-    loadModule = self._loadModule
+    self.initInfo["device"] = device
 
-    # make sure there are some arguments
+    # get GUI ID from the CLI argument
     if self.args.u:
-      GUIString = self.args.u[0]
-    else:
-      # GTK GUI fallback
-      GUIString = "GTK"
-    gs.GUIString = GUIString
+      self.GUIString = self.args.u
+    else: # no ID specified
+      # the N900 device module needs the GUIString
+      # at startup
+      if device == "n900":
+        self.GUIString = "GTK"
+    gs.GUIString = self.GUIString
 
     ## load the device specific module
 
@@ -185,28 +203,53 @@ class ModRana:
     # during init
     deviceModulesPath = os.path.join(modulesFolder, "device_modules")
     sys.path.append(deviceModulesPath)
-    dmod = loadModule("device_%s" % device, "device")
+    dmod = self._loadModule("device_%s" % device, "device")
     if dmod is None:
       print("modRana: no device module name provided"
-            "loading the Neo device module as failsafe")
+            "loading the Neo device module as fail-safe")
       device = "neo"
-      dmod = loadModule("device_%s" % device, "device")
+      dmod = self._loadModule("device_%s" % device, "device")
     self.dmod = dmod
 
-    ## load the GUI module
+    # if no GUIString was specified from CLI,
+    # get preferred GUI module strings from the device module
+
+    if self.GUIString == "":
+      ids = self.dmod.getSupportedGUIModuleIds()
+      if ids:
+        self.GUIString = ids[0]
+      else:
+        self.GUIString = "GTK" # fallback
+      # export the GUI string
+      gs.GUIString = self.GUIString
+
+    # TODO: if loading GUI module fails, retry other modules in
+    # order of preference as provided by the  device module
+
+  def _loadGUIModule(self):
+    """load the GUI module"""
 
     # add the GUI module folder to path
     GUIModulesPath = os.path.join(modulesFolder, "gui_modules")
     sys.path.append(GUIModulesPath)
-    if GUIString == "GTK":
-      gui = loadModule("gui_gtk", "gui")
-    elif GUIString == "QML":
-      gui = loadModule("gui_qml", "gui")
+
+    if self.GUIString == "GTK":
+      gui = self._loadModule("gui_gtk", "gui")
+    elif self.GUIString == "QML":
+      gui = self._loadModule("gui_qml", "gui")
       # make device module available to the GUI module
     if gui:
-      gui.dmod = dmod
+      gui.dmod = self.dmod
     self.gui = gui
 
+  def _loadModules(self):
+    """load all "normal" (other than device & GUI) modules"""
+
+    print("importing modules:")
+    start = time.clock()
+
+    # make shortcut for the loadModule function
+    loadModule = self._loadModule
 
     # get possible module names
     moduleNames = self._getModuleNamesFromFolder(modulesFolder)
@@ -216,7 +259,7 @@ class ModRana:
         moduleName = moduleName.split('.')[0]
         loadModule(moduleName, moduleName[4:])
 
-    print "Loaded all modules in %1.2f ms, initialising" % (1000 * (time.clock() - start))
+    print("Loaded all modules in %1.2f ms, initialising" % (1000 * (time.clock() - start)))
     self.addTime("all modules loaded")
 
     # make sure all modules have the device module and other variables before first time
@@ -231,7 +274,7 @@ class ModRana:
     for m in self.m.values():
       m.firstTime()
 
-      # run what needs to be done after firstTime is called
+    # run what needs to be done after firstTime is called
     self._modulesLoadedPostFirstTime()
 
     print( "Initialization complete in %1.2f ms" % (1000 * (time.clock() - start)) )
@@ -282,6 +325,10 @@ class ModRana:
     if 'showRedrawTime' in self.d and self.d['showRedrawTime'] == True:
       self.showRedrawTime = True
 
+    # run any tasks specified by CLI arguments
+    self.startup.handlePostFirstTimeTasks()
+
+
   def getModule(self, name, default=None):
     """
     return a given module instance, return default if no instance
@@ -713,8 +760,6 @@ if __name__ == "__main__":
     subprocess.call(callArgs)
 
   else:
-    print(" == modRana Starting == ")
-
     program = ModRana()
 
 
