@@ -86,7 +86,7 @@ class Options(ranaModule):
       
     if registerToMenu: # add to options menu structure ?
       self.menuModule.addItem(catId, name, icon, action)
-    if backButtonAction != None:
+    if backButtonAction is not None:
       self.options[id] = [backButtonAction ,0,[]]
     else:
       self.options[id] = ["set:menu:%s" % catId,0,[]]
@@ -145,7 +145,7 @@ class Options(ranaModule):
     menu = self.menuModule.getClearedMenu(backAction)
     menuItems = [] # an ordered list of all the menu items
     itemDict = {} # for easily assigning keys to labels
-    if fakeMode != None:
+    if fakeMode is not None:
       mode = fakeMode
     else:
       mode = self.get('mode', 'car')
@@ -157,7 +157,7 @@ class Options(ranaModule):
 
       menuItems.append(item)
       itemDict[key] = (name,id)
-      id = id + 1
+      id += 1
     # load all items to the menu
     menu = self.menuModule.addItemsToThisMenu(menu, menuItems)
     # store the menu in the menu module
@@ -176,7 +176,7 @@ class Options(ranaModule):
               'itemDict' : itemDict,
               'storageKey' : storageKey}
     # this means we are probably showing the option in the per mode state list
-    if fakeMode != None:
+    if fakeMode is not None:
       choices['mode'] = fakeMode
       choices['noToolsIcon'] = True # disable the tools in the per mode state list
     self.addOption(title, variable, choices, group, default)
@@ -423,7 +423,7 @@ class Options(ranaModule):
         themeList = icons.getThemeList()
         # check if current theme exists
         currentTheme = self.get('currentTheme', None)
-        if currentTheme != None:
+        if currentTheme is not None:
           if currentTheme not in themeList:
             self.set('currentTheme', defaultTheme) # theme not valid, reset to default
 
@@ -681,7 +681,7 @@ class Options(ranaModule):
     group = addGroup("Network usage", "network_usage", catNetwork, "generic")
     addOpt("Network", "network",
 #      [("off","No use of network"), #TODO: implement this :)
-      [("minimal", "Only for important data"),
+      [("minimal", "Don't Download Map Tiles"),
        ("full", "Unlimited use of network")],
        group,
        "full")
@@ -799,8 +799,8 @@ class Options(ranaModule):
     for category,options in self.options.items():
       for option in options[2]:
         (title,variable,choices,category,default) = option
-        if(default != None):
-          if(not self.d.has_key(variable)):
+        if default is not None:
+          if not self.d.has_key(variable):
             self.set(variable, default)
 
   def _removeNonPersistent(self, inputDict):
@@ -851,7 +851,7 @@ class Options(ranaModule):
       elif direction == "down" and index < maxIndex:
         newIndex = index + 1
         self.options[menuName][1] = newIndex
-    elif(message == "save"):
+    elif message == "save":
       self.modrana._saveOptions()
 
     elif type == 'ml' and message == "go2ItemToolsMenu":
@@ -971,7 +971,7 @@ class Options(ranaModule):
         index = firstItemIndex + row
         numItems = len(options)
         cAction = None
-        if(0 <= index < numItems):
+        if 0 <= index < numItems:
           (title,variable,choices,group,default) = options[index]
           # What's it set to currently?
           if 'mode' in choices:
@@ -1029,7 +1029,7 @@ class Options(ranaModule):
             valueDescription = "<tt><b>%s</b></tt>" % valueDescription
 
             #assure highlighting
-            if highlightId != None:
+            if highlightId is not None:
               """ run an action before switching to the next menu that
               assures that items in the next menu are properly highlighted
               according to the state of the corresponding variable"""
@@ -1046,10 +1046,10 @@ class Options(ranaModule):
             useNext = False
             for c in states:
               (cVal, cName) = (c[0],c[1])
-              if(useNext):
+              if useNext:
                 nextChoice = c
                 useNext = False
-              if(str(value) == str(cVal)):
+              if str(value) == str(cVal):
                 valueDescription = cName
                 useNext = True
                 if len(c) == 3:
@@ -1064,7 +1064,7 @@ class Options(ranaModule):
             onClick += "|set:needRedraw:1"
 
 
-          y = y4 + (row) * dy
+          y = y4 + row * dy
           if w1 > h1: # landscape
             dx = (x4-x1)
             w = w1 - dx
